Introduction
============


.. image:: https://readthedocs.org/projects/mindwidgets-circuitpython-df1201s-library/badge/?version=latest
    :target: https://mindwidgets-circuitpython-df1201s-library.readthedocs.io/
    :alt: Documentation Status



.. image:: https://img.shields.io/discord/327254708534116352.svg
    :target: https://adafru.it/discord
    :alt: Discord


.. image:: https://github.com/mindwidgets/Mindwidgets_CircuitPython_DF1201S/workflows/Build%20CI/badge.svg
    :target: https://github.com/mindwidgets/Mindwidgets_CircuitPython_DF1201S/actions
    :alt: Build Status


.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

CircuitPython driver for DFRobot DFPlayer Pro MP3 player with onboard storage


Dependencies
=============
This driver depends on:

* `Adafruit CircuitPython <https://github.com/adafruit/circuitpython>`_

Please ensure all dependencies are available on the CircuitPython filesystem.
This is easily achieved by downloading
`the Adafruit library and driver bundle <https://circuitpython.org/libraries>`_
or individual libraries can be installed using
`circup <https://github.com/adafruit/circup>`_.

Installing from PyPI
=====================
.. note:: This library is not available on PyPI yet. Install documentation is included as a standard element. Stay tuned for PyPI availability!

On supported GNU/Linux systems like the Raspberry Pi, you can install the driver locally `from
PyPI <https://pypi.org/project/mindwidgets-circuitpython-df1201s/>`_.
To install for current user:

.. code-block:: shell

    pip3 install mindwidgets-circuitpython-df1201s

To install system-wide (this may be required in some cases):

.. code-block:: shell

    sudo pip3 install mindwidgets-circuitpython-df1201s

To install in a virtual environment in your current project:

.. code-block:: shell

    mkdir project-name && cd project-name
    python3 -m venv .venv
    source .env/bin/activate
    pip3 install mindwidgets-circuitpython-df1201s

Installing to a Connected CircuitPython Device with Circup
==========================================================

Make sure that you have ``circup`` installed in your Python environment.
Install it with the following command if necessary:

.. code-block:: shell

    pip3 install circup

With ``circup`` installed and your CircuitPython device connected use the
following command to install:

.. code-block:: shell

    circup install df1201s

Or the following command to update an existing version:

.. code-block:: shell

    circup update

Usage Example
=============

.. code-block:: python

    import board
    import busio
    from mindwidgets_df1201s import DF1201S

    uart = busio.UART(tx=board.GP16, rx=board.GP17, baudrate=115200)

    df_player = DF1201S(uart)
    df_player.volume = 0.2
    df_player.play_mode = DF1201S.PLAYMODE_PLAY_ONCE

    if not df_player.play_next():
        print("No sound files to play!")

    while True:
        pass


Documentation
=============
API documentation for this library can be found on `Read the Docs <https://circuitpython-df1201s.readthedocs.io/>`_.

For information on building library documentation, please check out
`this guide <https://learn.adafruit.com/creating-and-sharing-a-circuitpython-library/sharing-our-docs-on-readthedocs#sphinx-5-1>`_.

Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/mindwidgets/Mindwidgets_CircuitPython_DF1201S/blob/HEAD/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.
